@@ -1,31 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 2014 Kurt Pattyn <pattyn.kurt@gmail.com>.
-** Contact: http://www.qt-project.org/legal
+** Copyright (C) 2016 Kurt Pattyn <pattyn.kurt@gmail.com>.
+** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of the QtWebSockets module of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL21$
+** $QT_BEGIN_LICENSE:LGPL$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia. For licensing terms and
-** conditions see http://qt.digia.com/licensing. For further information
-** use the contact form at http://qt.digia.com/contact-us.
+** a written agreement between you and The Qt Company. For licensing terms
+** and conditions see https://www.qt.io/terms-conditions. For further
+** information use the contact form at https://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 or version 3 as published by the Free
-** Software Foundation and appearing in the file LICENSE.LGPLv21 and
-** LICENSE.LGPLv3 included in the packaging of this file. Please review the
-** following information to ensure the GNU Lesser General Public License
-** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 3 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL3 included in the
+** packaging of this file. Please review the following information to
+** ensure the GNU Lesser General Public License version 3 requirements
+** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
 **
-** In addition, as a special exception, Digia gives you certain additional
-** rights. These rights are described in the Digia Qt LGPL Exception
-** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 2.0 or (at your option) the GNU General
+** Public license version 3 or any later version approved by the KDE Free
+** Qt Foundation. The licenses are as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
+** included in the packaging of this file. Please review the following
+** information to ensure the GNU General Public License requirements will
+** be met: https://www.gnu.org/licenses/gpl-2.0.html and
+** https://www.gnu.org/licenses/gpl-3.0.html.
 **
 ** $QT_END_LICENSE$
 **
@@ -61,14 +67,14 @@ QT_BEGIN_NAMESPACE
 QWebSocketFrame::QWebSocketFrame() :
     m_closeCode(QWebSocketProtocol::CloseCodeNormal),
     m_closeReason(),
-    m_isFinalFrame(true),
     m_mask(0),
-    m_rsv1(0),
-    m_rsv2(0),
-    m_rsv3(0),
     m_opCode(QWebSocketProtocol::OpCodeReservedC),
     m_length(0),
     m_payload(),
+    m_isFinalFrame(true),
+    m_rsv1(false),
+    m_rsv2(false),
+    m_rsv3(false),
     m_isValid(false)
 {
 }
@@ -79,14 +85,14 @@ QWebSocketFrame::QWebSocketFrame() :
 QWebSocketFrame::QWebSocketFrame(const QWebSocketFrame &other) :
     m_closeCode(other.m_closeCode),
     m_closeReason(other.m_closeReason),
-    m_isFinalFrame(other.m_isFinalFrame),
     m_mask(other.m_mask),
-    m_rsv1(other.m_rsv1),
-    m_rsv2(other.m_rsv2),
-    m_rsv3(other.m_rsv3),
     m_opCode(other.m_opCode),
     m_length(other.m_length),
     m_payload(other.m_payload),
+    m_isFinalFrame(other.m_isFinalFrame),
+    m_rsv1(other.m_rsv1),
+    m_rsv2(other.m_rsv2),
+    m_rsv3(other.m_rsv3),
     m_isValid(other.m_isValid)
 {
 }
@@ -102,7 +108,7 @@ QWebSocketFrame &QWebSocketFrame::operator =(const QWebSocketFrame &other)
     m_mask = other.m_mask;
     m_rsv1 = other.m_rsv1;
     m_rsv2 = other.m_rsv2;
-    m_rsv3 = other.m_rsv2;
+    m_rsv3 = other.m_rsv3;
     m_opCode = other.m_opCode;
     m_length = other.m_length;
     m_payload = other.m_payload;
@@ -118,14 +124,14 @@ QWebSocketFrame &QWebSocketFrame::operator =(const QWebSocketFrame &other)
 QWebSocketFrame::QWebSocketFrame(QWebSocketFrame &&other) :
     m_closeCode(qMove(other.m_closeCode)),
     m_closeReason(qMove(other.m_closeReason)),
-    m_isFinalFrame(qMove(other.m_isFinalFrame)),
     m_mask(qMove(other.m_mask)),
-    m_rsv1(qMove(other.m_rsv1)),
-    m_rsv2(qMove(other.m_rsv2)),
-    m_rsv3(qMove(other.m_rsv3)),
     m_opCode(qMove(other.m_opCode)),
     m_length(qMove(other.m_length)),
     m_payload(qMove(other.m_payload)),
+    m_isFinalFrame(qMove(other.m_isFinalFrame)),
+    m_rsv1(qMove(other.m_rsv1)),
+    m_rsv2(qMove(other.m_rsv2)),
+    m_rsv3(qMove(other.m_rsv3)),
     m_isValid(qMove(other.m_isValid))
 {}
 
@@ -236,30 +242,6 @@ quint32 QWebSocketFrame::mask() const
     return m_mask;
 }
 
-/*!
-    \internal
- */
-int QWebSocketFrame::rsv1() const
-{
-    return m_rsv1;
-}
-
-/*!
-    \internal
- */
-int QWebSocketFrame::rsv2() const
-{
-    return m_rsv2;
-}
-
-/*!
-    \internal
- */
-int QWebSocketFrame::rsv3() const
-{
-    return m_rsv3;
-}
-
 /*!
     \internal
  */
@@ -287,9 +269,9 @@ void QWebSocketFrame::clear()
     m_closeReason.clear();
     m_isFinalFrame = true;
     m_mask = 0;
-    m_rsv1 = 0;
-    m_rsv2 = 0;
-    m_rsv3 = 0;
+    m_rsv1 = false;
+    m_rsv2 = false;
+    m_rsv3 = false;
     m_opCode = QWebSocketProtocol::OpCodeReservedC;
     m_length = 0;
     m_payload.clear();
@@ -304,13 +286,6 @@ bool QWebSocketFrame::isValid() const
     return m_isValid;
 }
 
-// The arm compiler of Visual Studio 2013 Update 3 crashes when
-// trying to optimize QWebSocketFrame::readFrame. Hence turn
-// those off for this snippet
-#if (defined(Q_OS_WINPHONE) || defined(Q_OS_WINRT)) && defined(__ARM__)
-#  pragma optimize("", off)
-#endif
-
 #define WAIT_FOR_MORE_DATA(dataSizeInBytes)  \
     { returnState = processingState; \
       processingState = PS_WAIT_FOR_MORE_DATA; dataWaitSize = dataSizeInBytes; }
@@ -519,10 +494,6 @@ QWebSocketFrame QWebSocketFrame::readFrame(QIODevice *pIoDevice)
     return frame;
 }
 
-#if (defined(Q_OS_WINPHONE) || defined(Q_OS_WINRT)) && defined(__ARM__)
-#  pragma optimize("", on)
-#endif
-
 /*!
     \internal
  */
@@ -546,10 +517,10 @@ bool QWebSocketFrame::checkValidity()
     } else if (isControlFrame()) {
         if (Q_UNLIKELY(m_length > 125)) {
             setError(QWebSocketProtocol::CloseCodeProtocolError,
-                     tr("Controle frame is larger than 125 bytes"));
+                     tr("Control frame is larger than 125 bytes"));
         } else if (Q_UNLIKELY(!m_isFinalFrame)) {
             setError(QWebSocketProtocol::CloseCodeProtocolError,
-                     tr("Controle frames cannot be fragmented"));
+                     tr("Control frames cannot be fragmented"));
         } else {
             m_isValid = true;
         }
